@@ -182,6 +182,10 @@ class Node(BaseModel, T.Generic[InsertType]):
         resolver_type: T.ClassVar[T.Type["ResolverType"]]
         updatable_fields: T.ClassVar[T.Set[str]] = set()
 
+    @classmethod
+    def get_aliases(cls) -> T.Set[str]:
+        return {field.alias for field in cls.__fields__.values()}
+
     def __eq__(self, other: TempNodeType) -> bool:
         if not isinstance(other, Node):
             return False
